/*
 ============================================================================
 Name		: DialogExamDocument.h
 Author	  : Hou maoqing
 Copyright   : Copyright (c) Hou maoqing 2008
 Description : Declares document class for application.
 ============================================================================
 */

#ifndef __DIALOGEXAMDOCUMENT_h__
#define __DIALOGEXAMDOCUMENT_h__

// INCLUDES
#include <akndoc.h>

// FORWARD DECLARATIONS
class CDialogExamAppUi;
class CEikApplication;

// CLASS DECLARATION

/**
 * CDialogExamDocument application class.
 * An instance of class CDialogExamDocument is the Document part of the
 * AVKON application framework for the DialogExam example application.
 */
class CDialogExamDocument : public CAknDocument
	{
public:
	// Constructors and destructor

	/**
	 * NewL.
	 * Two-phased constructor.
	 * Construct a CDialogExamDocument for the AVKON application aApp
	 * using two phase construction, and return a pointer
	 * to the created object.
	 * @param aApp Application creating this document.
	 * @return A pointer to the created instance of CDialogExamDocument.
	 */
	static CDialogExamDocument* NewL(CEikApplication& aApp);

	/**
	 * NewLC.
	 * Two-phased constructor.
	 * Construct a CDialogExamDocument for the AVKON application aApp
	 * using two phase construction, and return a pointer
	 * to the created object.
	 * @param aApp Application creating this document.
	 * @return A pointer to the created instance of CDialogExamDocument.
	 */
	static CDialogExamDocument* NewLC(CEikApplication& aApp);

	/**
	 * ~CDialogExamDocument
	 * Virtual Destructor.
	 */
	virtual ~CDialogExamDocument();

public:
	// Functions from base classes

	/**
	 * CreateAppUiL
	 * From CEikDocument, CreateAppUiL.
	 * Create a CDialogExamAppUi object and return a pointer to it.
	 * The object returned is owned by the Uikon framework.
	 * @return Pointer to created instance of AppUi.
	 */
	CEikAppUi* CreateAppUiL();

private:
	// Constructors

	/**
	 * ConstructL
	 * 2nd phase constructor.
	 */
	void ConstructL();

	/**
	 * CDialogExamDocument.
	 * C++ default constructor.
	 * @param aApp Application creating this document.
	 */
	CDialogExamDocument(CEikApplication& aApp);

	};

#endif // __DIALOGEXAMDOCUMENT_h__
// End of File
